@@ -1,15 +1,18 @@
 from weakref import WeakValueDictionary
 
-from param.parameterized import add_metaclass
-
-from ...streams import (
-    Stream, Selection1D, RangeXY, RangeX, RangeY, BoundsXY, BoundsX, BoundsY,
-    SelectionXY
-)
-
-from .util import _trace_to_subplot
-
 from ...element import Tiles
+from ...streams import (
+    BoundsX,
+    BoundsXY,
+    BoundsY,
+    RangeX,
+    RangeXY,
+    RangeY,
+    Selection1D,
+    SelectionXY,
+    Stream,
+)
+from .util import PLOTLY_MAP, PLOTLY_SCATTERMAP, _trace_to_subplot
 
 
 class PlotlyCallbackMetaClass(type):
@@ -31,15 +34,14 @@ class PlotlyCallbackMetaClass(type):
 
         # Store weak reference to the callback instance in the _instances
         # WeakValueDictionary. This will allow instances to be garbage collected and
-        # the references will be automatically removed from the colleciton when this
+        # the references will be automatically removed from the collection when this
         # happens.
         cls.instances[inst.plot.trace_uid] = inst
 
         return inst
 
 
-@add_metaclass(PlotlyCallbackMetaClass)
-class PlotlyCallback(object):
+class PlotlyCallback(metaclass=PlotlyCallbackMetaClass):
 
     def __init__(self, plot, streams, source, **params):
         self.plot = plot
@@ -114,7 +116,7 @@ class BoundsCallback(PlotlyCallback):
 
         # Initialize event data by clearing box selection on everything
         event_data = {}
-        for trace_ind, trace in enumerate(traces):
+        for trace in traces:
             trace_uid = trace.get('uid', None)
             if cls.boundsx and cls.boundsy:
                 stream_data = dict(bounds=None)
@@ -136,7 +138,7 @@ class BoundsCallback(PlotlyCallback):
     @classmethod
     def update_event_data_xyaxis(cls, range_data, traces, event_data):
         # Process traces
-        for trace_ind, trace in enumerate(traces):
+        for trace in traces:
             trace_type = trace.get('type', 'scatter')
             trace_uid = trace.get('uid', None)
 
@@ -166,14 +168,14 @@ class BoundsCallback(PlotlyCallback):
     @classmethod
     def update_event_data_mapbox(cls, range_data, traces, event_data):
         # Process traces
-        for trace_ind, trace in enumerate(traces):
+        for trace in traces:
             trace_type = trace.get('type', 'scatter')
             trace_uid = trace.get('uid', None)
 
-            if _trace_to_subplot.get(trace_type, None) != ['mapbox']:
+            if _trace_to_subplot.get(trace_type, None) != [PLOTLY_MAP]:
                 continue
 
-            mapbox_ref = trace.get('subplot', 'mapbox')
+            mapbox_ref = trace.get('subplot', PLOTLY_MAP)
             if mapbox_ref in range_data:
                 lon_bounds = [range_data[mapbox_ref][0][0], range_data[mapbox_ref][1][0]]
                 lat_bounds = [range_data[mapbox_ref][0][1], range_data[mapbox_ref][1][1]]
@@ -226,7 +228,7 @@ class RangeCallback(PlotlyCallback):
     def build_event_data_from_viewport(cls, traces, property_value):
         # Process traces
         event_data = {}
-        for trace_ind, trace in enumerate(traces):
+        for trace in traces:
             trace_type = trace.get('type', 'scatter')
             trace_uid = trace.get('uid', None)
 
@@ -235,8 +237,8 @@ class RangeCallback(PlotlyCallback):
 
             xaxis = trace.get('xaxis', 'x').replace('x', 'xaxis')
             yaxis = trace.get('yaxis', 'y').replace('y', 'yaxis')
-            xprop = '{xaxis}.range'.format(xaxis=xaxis)
-            yprop = '{yaxis}.range'.format(yaxis=yaxis)
+            xprop = f'{xaxis}.range'
+            yprop = f'{yaxis}.range'
 
             if not property_value:
                 x_range = None
@@ -265,14 +267,14 @@ class RangeCallback(PlotlyCallback):
     def build_event_data_from_relayout_data(cls, traces, property_value):
         # Process traces
         event_data = {}
-        for trace_ind, trace in enumerate(traces):
-            trace_type = trace.get('type', 'scattermapbox')
+        for trace in traces:
+            trace_type = trace.get('type', PLOTLY_SCATTERMAP)
             trace_uid = trace.get('uid', None)
 
-            if _trace_to_subplot.get(trace_type, None) != ['mapbox']:
+            if _trace_to_subplot.get(trace_type, None) != [PLOTLY_MAP]:
                 continue
 
-            subplot_id = trace.get("subplot", "mapbox")
+            subplot_id = trace.get("subplot", PLOTLY_MAP)
             derived_prop = subplot_id + "._derived"
 
             if not property_value:
