@@ -14,6 +14,7 @@ from ..plot import GenericElementPlot, GenericOverlayPlot
 from ..util import dim_range_key
 from .plot import PlotlyPlot
 from .util import (
+    PLOTLY_MAP,
     STYLE_ALIASES,
     get_colorscale,
     legend_trace_types,
@@ -35,7 +36,7 @@ class ElementPlot(PlotlyPlot, GenericElementPlot):
     bgcolor = param.ClassSelector(class_=(str, tuple), default=None, doc="""
         If set bgcolor overrides the background color of the axis.""")
 
-    invert_axes = param.ObjectSelector(default=False, doc="""
+    invert_axes = param.Selector(default=False, doc="""
         Inverts the axes of the plot. Note that this parameter may not
         always be respected by all plots but should be respected by
         adjoined plots when appropriate.""")
@@ -71,7 +72,7 @@ class ElementPlot(PlotlyPlot, GenericElementPlot):
     show_legend = param.Boolean(default=False, doc="""
         Whether to show legend for the plot.""")
 
-    xaxis = param.ObjectSelector(default='bottom',
+    xaxis = param.Selector(default='bottom',
                                  objects=['top', 'bottom', 'bare', 'top-bare',
                                           'bottom-bare', None], doc="""
         Whether and where to display the xaxis, bare options allow suppressing
@@ -82,7 +83,7 @@ class ElementPlot(PlotlyPlot, GenericElementPlot):
         Ticks along x-axis specified as an integer, explicit list of
         tick locations, list of tuples containing the locations.""")
 
-    yaxis = param.ObjectSelector(default='left',
+    yaxis = param.Selector(default='left',
                                       objects=['left', 'right', 'bare', 'left-bare',
                                                'right-bare', None], doc="""
         Whether and where to display the yaxis, bare options allow suppressing
@@ -208,8 +209,8 @@ class ElementPlot(PlotlyPlot, GenericElementPlot):
                 components[k].extend(datum_components.get(k, []))
 
             # Handle mapbox
-            if "mapbox" in datum_components:
-                components["mapbox"] = datum_components["mapbox"]
+            if PLOTLY_MAP in datum_components:
+                components[PLOTLY_MAP] = datum_components[PLOTLY_MAP]
 
         self.handles['components'] = components
 
@@ -219,8 +220,8 @@ class ElementPlot(PlotlyPlot, GenericElementPlot):
             layout.setdefault(k, [])
             layout[k].extend(components.get(k, []))
 
-        if "mapbox" in components:
-            merge_layout(layout.setdefault("mapbox", {}), components["mapbox"])
+        if PLOTLY_MAP in components:
+            merge_layout(layout.setdefault(PLOTLY_MAP, {}), components[PLOTLY_MAP])
 
         self.handles['layout'] = layout
 
@@ -534,7 +535,7 @@ class ElementPlot(PlotlyPlot, GenericElementPlot):
                     max_y_zoom = (np.log2(max_delta / y_delta) -
                                 np.log2(mapbox_tile_size / viewport_height))
                 mapbox["zoom"] = min(max_x_zoom, max_y_zoom)
-            layout["mapbox"] = mapbox
+            layout[PLOTLY_MAP] = mapbox
 
         if isinstance(self.projection, str) and self.projection == '3d':
             scene = dict(xaxis=xaxis, yaxis=yaxis)
