@@ -1,14 +1,14 @@
 import numpy as np
+import pytest
+from matplotlib.collections import LineCollection, PolyCollection
 
 from holoviews.core.data import Dataset
-from holoviews.core.options import Cycle
+from holoviews.core.options import AbbreviatedException, Cycle
 from holoviews.core.spaces import HoloMap
-from holoviews.element import Graph, Nodes, TriMesh, Chord, circular_layout
+from holoviews.element import Chord, Graph, Nodes, TriMesh, circular_layout
 from holoviews.util.transform import dim
-from matplotlib.collections import LineCollection, PolyCollection
-from packaging.version import Version
 
-from .test_plot import TestMPLPlot, mpl_renderer
+from .test_plot import MPL_GE_3_4_0, TestMPLPlot, mpl_renderer
 
 
 class TestMplGraphPlot(TestMPLPlot):
@@ -197,19 +197,19 @@ class TestMplGraphPlot(TestMPLPlot):
         self.assertEqual(artist.get_linewidths(), [12, 3, 5])
 
     def test_graph_op_node_alpha(self):
-        import matplotlib as mpl
         edges = [(0, 1), (0, 2)]
         nodes = Nodes([(0, 0, 0, 0.2), (0, 1, 1, 0.6), (1, 1, 2, 1)], vdims='alpha')
         graph = Graph((edges, nodes)).opts(node_alpha='alpha')
 
-        if Version(mpl.__version__) < Version("3.4.0"):
-            # Python 3.6 only support up to matplotlib 3.3
-            with self.assertRaises(Exception):
-                mpl_renderer.get_plot(graph)
-        else:
+        if MPL_GE_3_4_0:
             plot = mpl_renderer.get_plot(graph)
             artist = plot.handles['nodes']
             self.assertEqual(artist.get_alpha(), np.array([0.2, 0.6, 1]))
+        else:
+            # Python 3.6 only support up to matplotlib 3.3
+            msg = 'TypeError: alpha must be a float or None'
+            with pytest.raises(AbbreviatedException, match=msg):
+                mpl_renderer.get_plot(graph)
 
     def test_graph_op_edge_color(self):
         edges = [(0, 1, 'red'), (0, 2, 'green'), (1, 3, 'blue')]
@@ -272,7 +272,8 @@ class TestMplGraphPlot(TestMPLPlot):
     def test_graph_op_edge_alpha(self):
         edges = [(0, 1, 0.1), (0, 2, 0.5), (1, 3, 0.3)]
         graph = Graph(edges, vdims='alpha').opts(edge_alpha='alpha')
-        with self.assertRaises(Exception):
+        msg = 'ValueError: Mapping a dimension to the "edge_alpha" style'
+        with pytest.raises(AbbreviatedException, match=msg):
             mpl_renderer.get_plot(graph)
 
     def test_graph_op_edge_linewidth(self):
@@ -316,7 +317,7 @@ class TestMplTriMeshPlot(TestMPLPlot):
                          [p.array() for p in self.trimesh._split_edgepaths.split()])
 
     def test_plot_simple_trimesh_filled(self):
-        plot = mpl_renderer.get_plot(self.trimesh.opts(plot=dict(filled=True)))
+        plot = mpl_renderer.get_plot(self.trimesh.opts(filled=True))
         nodes = plot.handles['nodes']
         edges = plot.handles['edges']
         self.assertIsInstance(edges, PolyCollection)
@@ -389,20 +390,19 @@ class TestMplTriMeshPlot(TestMPLPlot):
         self.assertEqual(artist.get_sizes(), np.array([9, 4, 64, 16]))
 
     def test_trimesh_op_node_alpha(self):
-        import matplotlib as mpl
-
         edges = [(0, 1, 2), (1, 2, 3)]
         nodes = [(-1, -1, 0, 0.2), (0, 0, 1, 0.6), (0, 1, 2, 1), (1, 0, 3, 0.3)]
         trimesh = TriMesh((edges, Nodes(nodes, vdims='alpha'))).opts(node_alpha='alpha')
 
-        if Version(mpl.__version__) < Version("3.4.0"):
-            # Python 3.6 only support up to matplotlib 3.3
-            with self.assertRaises(Exception):
-                mpl_renderer.get_plot(trimesh)
-        else:
+        if MPL_GE_3_4_0:
             plot = mpl_renderer.get_plot(trimesh)
             artist = plot.handles['nodes']
             self.assertEqual(artist.get_alpha(), np.array([0.2, 0.6, 1, 0.3]))
+        else:
+            # Python 3.6 only support up to matplotlib 3.3
+            msg = "TypeError: alpha must be a float or None"
+            with pytest.raises(AbbreviatedException, match=msg):
+                mpl_renderer.get_plot(trimesh)
 
     def test_trimesh_op_node_line_width(self):
         edges = [(0, 1, 2), (1, 2, 3)]
@@ -452,7 +452,8 @@ class TestMplTriMeshPlot(TestMPLPlot):
         edges = [(0, 1, 2, 0.7), (1, 2, 3, 0.3)]
         nodes = [(-1, -1, 0), (0, 0, 1), (0, 1, 2), (1, 0, 3)]
         trimesh = TriMesh((edges, nodes), vdims='alpha').opts(edge_alpha='alpha')
-        with self.assertRaises(Exception):
+        msg = 'ValueError: Mapping a dimension to the "edge_alpha" style'
+        with pytest.raises(AbbreviatedException, match=msg):
             mpl_renderer.get_plot(trimesh)
 
     def test_trimesh_op_edge_line_width(self):
@@ -479,13 +480,13 @@ class TestMplChordPlot(TestMPLPlot):
         return Chord((edges, nodes), vdims='weight')
 
     def test_chord_nodes_label_text(self):
-        g = self.chord.opts(plot=dict(label_index='Label'))
+        g = self.chord.opts(label_index='Label')
         plot = mpl_renderer.get_plot(g)
         labels = plot.handles['labels']
         self.assertEqual([l.get_text() for l in labels], ['A', 'B', 'C'])
 
     def test_chord_nodes_labels_mapping(self):
-        g = self.chord.opts(plot=dict(labels='Label'))
+        g = self.chord.opts(labels='Label')
         plot = mpl_renderer.get_plot(g)
         labels = plot.handles['labels']
         self.assertEqual([l.get_text() for l in labels], ['A', 'B', 'C'])
@@ -512,8 +513,7 @@ class TestMplChordPlot(TestMPLPlot):
         self.assertEqual(arcs.get_clim(), (0, 2))
 
     def test_chord_edges_categorically_colormapped(self):
-        g = self.chord.opts(plot=dict(edge_color_index='start'),
-                            style=dict(edge_cmap=['#FFFFFF', '#000000']))
+        g = self.chord.opts(edge_color_index='start', edge_cmap=['#FFFFFF', '#000000'])
         plot = mpl_renderer.get_plot(g)
         edges = plot.handles['edges']
         colors = np.array([[ 1., 1., 1., 1. ],
